package com.sf.statistics.processors;

package ..deTemp.1735180518396;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollectionUtil;
import cn.hutool.core.util.ObjectUtil;
import com.github.kfcfans.powerjob.worker.core.processor.ProcessResult;
import com.github.kfcfans.powerjob.worker.core.processor.TaskContext;
import com.sf.dms.job.AbstractJobProcessor;
import com.sf.statistics.processors.bean.ScadaEventInfo;
import com.smartframework.web.core.utils.Constants;
import com.smartframework.web.core.utils.ParameterUtils;
import com.smartframework.web.core.utils.SimpleJdbcClient;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Calendar;
import java.util.Comparator;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.concurrent.ConcurrentHashMap;
import java.util.function.Function;
import java.util.function.Predicate;
import java.util.stream.Collectors;
import org.apache.commons.lang.StringUtils;
import org.apache.logging.log4j.util.Strings;

public class YkYxProcessor extends AbstractJobProcessor {
  static int YX_RIGHT = 0;
  
  static int YX_WRONG = 1;
  
  static int YK_SUCCEED = 0;
  
  static int YK_FAIL = 1;
  
  static int YK_USE = 0;
  
  static int YK_NOT_USE = 1;
  
  static int EXCLUDE_REASON_NONE = 0;
  
  static int EXCLUDE_REASON_TOKEN = 1;
  
  static int EXCLUDE_REASON_FAULT = 2;
  
  static int EXCLUDE_REASON_SHAKE = 3;
  
  static int EXCLUDE_REASON_SWITCH = 4;
  
  static int EXCLUDE_REASON_RESTORATION = 5;
  
  static int YX_STANDARD_SECOND = 15;
  
  static int YK_STANDARD_SECOND = 30;
  
  static int YK_WAIT_SECOND = 30;
  
  static int YKUSE_SGZ_SECOND = 30;
  
  static int YKUSE_GZTZ_SECOND = 30;
  
  static int YKUSE_SUCCESS_SECOND = 30;
  
  static int YK_EXECUTION_SUCCESS_DELAY_SECOND = 3;
  
  static Integer[] YK_RESULT_STATUS = new Integer[] { Integer.valueOf(12), Integer.valueOf(17), Integer.valueOf(18), Integer.valueOf(36), Integer.valueOf(37) };
  
  static Integer[] YK_STATUS = new Integer[] { 
      Integer.valueOf(11), Integer.valueOf(12), Integer.valueOf(13), Integer.valueOf(14), Integer.valueOf(15), Integer.valueOf(16), Integer.valueOf(17), Integer.valueOf(18), Integer.valueOf(30), Integer.valueOf(31), 
      Integer.valueOf(32), Integer.valueOf(33), Integer.valueOf(34), Integer.valueOf(35), Integer.valueOf(36), Integer.valueOf(37) };
  
  static int DEBUG_FLAG = -1;
  
  static int NOT_STATISTICS_FLAG = -1;
  
  static String YX_TABLE = "scada_event_yx";
  
  static String YX_TABLE_NEW = "statistics_scada_event_yx";
  
  static String YK_TABLE = "scada_event_yk";
  
  static String YK_TABLE_NEW = "statistics_scada_event_yk";
  
  static String YKUSE_TABLE = "scada_event_ykuse";
  
  static String YKUSE_TABLE_NEW = "statistics_scada_event_ykuse";
  
  static List<String> YKYX_DEF_SGZ = new ArrayList<>();
  
  private void init(SimpleJdbcClient jdbcClient) {
    String ykyxDefSgz = Constants.getString("ykyx.def.sgz", "sgz");
    List<String> list = Arrays.asList(ykyxDefSgz.split(","));
    YKYX_DEF_SGZ.addAll(list);
    String menuSql = "select * from sys_menu where menu_name = 'scada_equipment_status'";
    List<Map<String, Object>> menuList = jdbcClient.queryForList(menuSql);
    menuList.forEach(map -> {
          String menuMacroName = (String)map.get("menuMacroName");
          if (StringUtils.equalsIgnoreCase(menuMacroName, "MENU_STATE_DEV_DEBUGING")) {
            DEBUG_FLAG = ((Integer)map.get("actualValue")).intValue();
          } else if (StringUtils.equalsIgnoreCase(menuMacroName, "MENU_STATE_DEV_INHIBIT_STATISTICS")) {
            NOT_STATISTICS_FLAG = ((Integer)map.get("actualValue")).intValue();
          } 
        });
  }
  
  protected ProcessResult execute(TaskContext taskContext, Map<String, String> map) throws Exception {
    String startDateStr = map.get("startDate");
    String endDateStr = map.get("endDate");
    SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
    Date startDate = null;
    Date endDate = null;
    if (StringUtils.isNotBlank(startDateStr) && StringUtils.isNotBlank(endDateStr))
      try {
        startDate = sdf.parse(startDateStr);
        endDate = sdf.parse(endDateStr);
      } catch (ParseException e) {
        return new ProcessResult(false, "时间参数有误");
      }  
    if (startDate == null || endDate == null) {
      Calendar calendarEnd = Calendar.getInstance();
      calendarEnd.setTime(new Date());
      calendarEnd.set(11, 0);
      calendarEnd.set(12, 0);
      calendarEnd.set(13, 0);
      calendarEnd.set(14, 0);
      endDate = calendarEnd.getTime();
      Calendar calendarStart = Calendar.getInstance();
      calendarStart.setTime(endDate);
      calendarStart.add(5, -1);
      startDate = calendarStart.getTime();
    } 
    logToServer("statisticsYkYx: from " + sdf.format(startDate) + " to " + sdf.format(endDate));
    SimpleJdbcClient jdbcClient = buildJdbcClient("smartsys");
    SimpleJdbcClient rthdbClient = buildJdbcClient("rthdb");
    if (ParameterUtils.isEmptyOrNull(jdbcClient) || ParameterUtils.isEmptyOrNull(rthdbClient)) {
      logToServer("获取smartsys或者rthdb数据库配置为空，请检查app.properties文件中是否配置了smartsys开通的数据库配置信息及rthdb开头的实时库信息");
    } else {
      init(jdbcClient);
      statisticsYkYx(jdbcClient, rthdbClient, startDate, endDate);
    } 
    return new ProcessResult(true, "遥控遥信统计");
  }
  
  private void statisticsYkYx(SimpleJdbcClient jdbcClient, SimpleJdbcClient rthdbClient, Date startDate, Date endDate) throws Exception {
    SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
    boolean ykyxUseNewTable = Constants.getBoolean("ykyx.use.new.table", false);
    String selectStartDateStr = sdf.format(new Date(startDate.getTime() - 60000L));
    String selectEndDateStr = sdf.format(new Date(endDate.getTime() + 60000L));
    String scadaEventSql = "select e.context, e.occur_time, e.milli_second,e.infer_name, soe_time, soe_msecond, e.obj_id, e.alarm_type, e.status, e.dev_id, e.container1_id as feeder_id, e.station_id, con_station.container_id as division_id, e.content, e.reason_code, e.sysid,pnt_dig.postfix, pnt_dig.is_control,pnt_dig.filter,fes_dig.rtu_id,fes_rtu.type as rtu_type, fes_rtu.comm_type, fes_rtu.manu_fac, fes_rtu.is_transmit from scada_event e inner join pnt_dig on pnt_dig.id = e.obj_id inner join fes_dig on fes_dig.scada_pnt_id = e.obj_id inner join fes_rtu on fes_rtu.id = fes_dig.rtu_id left join con_station on con_station.id = e.station_id and con_station.container_tablename = 'con_division' where e.alarm_type in (1,3,4,13) and e.context in (1,2) and pnt_dig.postfix in (%s) and e.occur_time >= '%s' and e.occur_time < '%s'";
    List<String> postfixList = new ArrayList<>(YKYX_DEF_SGZ);
    postfixList.add("pos");
    postfixList = (List<String>)postfixList.stream().map(l -> "'" + l + "'").collect(Collectors.toList());
    String postfixStr = Strings.join(postfixList, ',');
    String dataSql = String.format(scadaEventSql, new Object[] { postfixStr, selectStartDateStr, selectEndDateStr });
    logToServer("dataSql" + dataSql);
    List<Map<String, Object>> scadaEventList = jdbcClient.queryForList(dataSql);
    logToServer(String.format("查询%s到%s的scada_event记录，总共%d条", new Object[] { selectStartDateStr, selectEndDateStr, Integer.valueOf(scadaEventList.size()) }));
    List<ScadaEventInfo> scadaEvents = (List<ScadaEventInfo>)scadaEventList.stream().map(map -> (ScadaEventInfo)BeanUtil.fillBeanWithMap(map, new ScadaEventInfo(), false)).filter(event -> {
          if (ObjectUtil.equals(event.getAlarmType(), Integer.valueOf(13)))
            return ObjectUtil.equals(event.getStatus(), Integer.valueOf(1)); 
          boolean isPos = ((StringUtils.equalsIgnoreCase("breaker", event.getFilter()) || StringUtils.equalsIgnoreCase("switch", event.getFilter())) && StringUtils.equalsIgnoreCase("pos", event.getPostfix()));
          boolean isSGZ = YKYX_DEF_SGZ.contains(event.getPostfix());
          return (isPos || isSGZ);
        }).filter(distinctByKey(ScadaEventInfo::getPKey)).collect(Collectors.toList());
    Map<Long, Integer> devStatusMap = new HashMap<>();
    List<String> devIdList = (List<String>)scadaEvents.stream().map(ScadaEventInfo::getDevId).filter(devId -> (devId != null && devId.longValue() > 1L)).distinct().map(String::valueOf).collect(Collectors.toList());
    if (CollectionUtil.isNotEmpty(devIdList)) {
      String devIdListStr = String.join(",", (Iterable)devIdList);
      String localStatusSql = "select container_id as dev_id,value from real_scada_pnt_dig where postfix = 'loc' and container_id in (" + devIdListStr + ")";
      List<Map<String, Object>> localStatusList = rthdbClient.queryForList(localStatusSql);
      logToServer(String.format("查询远方就地记录，总共%d条", new Object[] { Integer.valueOf(localStatusList.size()) }));
      localStatusList.forEach(map -> {
            Long devId = (Long)map.get("devId");
            Integer status = (Integer)map.get("value");
            devStatusMap.put(devId, status);
          });
    } 
    scadaEvents = (List<ScadaEventInfo>)scadaEvents.stream().filter(event -> !isDebugOrNotStatistics(event.getReasonCode())).collect(Collectors.toList());
    logToServer("开始处理遥信正确率");
    List<ScadaEventInfo> yxList = BeanUtil.copyToList(scadaEvents, ScadaEventInfo.class);
    yxList = (List<ScadaEventInfo>)yxList.stream().filter(yx -> {
          boolean isReal = ObjectUtil.equals(yx.getContext(), Integer.valueOf(1));
          boolean isPos = ((StringUtils.equalsIgnoreCase("breaker", yx.getFilter()) || StringUtils.equalsIgnoreCase("switch", yx.getFilter())) && StringUtils.equalsIgnoreCase("pos", yx.getPostfix()));
          boolean isChangeOrSOE = (ObjectUtil.equals(yx.getAlarmType(), Integer.valueOf(1)) || ObjectUtil.equals(yx.getAlarmType(), Integer.valueOf(3)));
          return (isReal && isPos && isChangeOrSOE);
        }).collect(Collectors.toList());
    procYxAccuracy(getEventMap(yxList));
    logToServer(String.format("处理遥信正确率结束，总共%d条", new Object[] { Integer.valueOf(yxList.size()) }));
    clearOldAndInsertNewData(jdbcClient, ykyxUseNewTable ? YX_TABLE_NEW : YX_TABLE, yxList, startDate, endDate, sdf.format(startDate), sdf.format(endDate));
    logToServer("开始处理遥控成功率");
    List<ScadaEventInfo> ykList = BeanUtil.copyToList(scadaEvents, ScadaEventInfo.class);
    boolean ykIgnoreReturnTimeout = Constants.getBoolean("ykyx.yk.ignore.return.timeout", false);
    boolean ykIgnoreFutureState = Constants.getBoolean("ykyx.yk.ignore.future.state", true);
    ykList = (List<ScadaEventInfo>)ykList.stream().filter(yk -> {
          boolean isHandleState = true;
          if (ykIgnoreFutureState)
            isHandleState = ObjectUtil.equals(yk.getContext(), Integer.valueOf(1)); 
          boolean isPos = ((StringUtils.equalsIgnoreCase("breaker", yk.getFilter()) || StringUtils.equalsIgnoreCase("switch", yk.getFilter())) && StringUtils.equalsIgnoreCase("pos", yk.getPostfix()));
          boolean isYk = ObjectUtil.equals(yk.getAlarmType(), Integer.valueOf(4));
          boolean isControl = ObjectUtil.equals(yk.getIsControl(), Integer.valueOf(1));
          boolean isYkStatus = Arrays.<Integer>asList(YK_STATUS).contains(yk.getStatus());
          if (isYkStatus && ykIgnoreReturnTimeout)
            isYkStatus = ObjectUtil.notEqual(yk.getStatus(), Integer.valueOf(37)); 
          return (isHandleState && isPos && isYk && isControl && isYkStatus);
        }).collect(Collectors.toList());
    procYkSuccess(getEventMap(ykList));
    logToServer(String.format("处理遥控成功率结束，总共%d条", new Object[] { Integer.valueOf(ykList.size()) }));
    clearOldAndInsertNewData(jdbcClient, ykyxUseNewTable ? YK_TABLE_NEW : YK_TABLE, ykList, startDate, endDate, sdf.format(startDate), sdf.format(endDate));
    logToServer("开始处理遥控使用率");
    List<ScadaEventInfo> ykUseList = BeanUtil.copyToList(scadaEvents, ScadaEventInfo.class);
    boolean ykuseNeedSoe = Constants.getBoolean("ykyx.ykuse.need.soe", false);
    boolean ykuseOnlyLocal = Constants.getBoolean("ykyx.ykuse.only.local", false);
    boolean ykuseAllYk = Constants.getBoolean("ykyx.ykuse.all.yk", false);
    List<ScadaEventInfo> finalYkUseList = ykUseList;
    ykUseList = (List<ScadaEventInfo>)ykUseList.stream().filter(ykUse -> {
          boolean isHandleState;
          if (ykIgnoreFutureState) {
            isHandleState = ObjectUtil.equals(ykUse.getContext(), Integer.valueOf(1));
          } else {
            isHandleState = (!ObjectUtil.equals(ykUse.getContext(), Integer.valueOf(2)) || (!ObjectUtil.equals(ykUse.getAlarmType(), Integer.valueOf(1)) && !ObjectUtil.equals(ykUse.getAlarmType(), Integer.valueOf(13))));
          } 
          boolean isControl = ObjectUtil.equals(ykUse.getIsControl(), Integer.valueOf(1));
          boolean isYkUse = (ObjectUtil.equals(ykUse.getAlarmType(), Integer.valueOf(1)) || ObjectUtil.equals(ykUse.getAlarmType(), Integer.valueOf(13)));
          boolean isPos = ((StringUtils.equalsIgnoreCase("breaker", ykUse.getFilter()) || StringUtils.equalsIgnoreCase("switch", ykUse.getFilter())) && StringUtils.equalsIgnoreCase("pos", ykUse.getPostfix()));
          int yxStatus = ykuseAllYk ? 16 : 17;
          boolean isYkExecution = (ObjectUtil.equals(ykUse.getAlarmType(), Integer.valueOf(4)) && ObjectUtil.equals(ykUse.getStatus(), Integer.valueOf(yxStatus)));
          boolean isSGZ = YKYX_DEF_SGZ.contains(ykUse.getPostfix());
          Long devId = ykUse.getDevId();
          if (ykuseOnlyLocal && devId != null && devId.longValue() >= 1L) {
            Integer status = (Integer)devStatusMap.get(devId);
            if (status != null && status.intValue() == 1)
              return false; 
          } 
          if (ObjectUtil.equals(ykUse.getAlarmType(), Integer.valueOf(1)) && ykuseNeedSoe) {
            ScadaEventInfo soe = finalYkUseList.stream().filter(()).findFirst().orElse(null);
            if (soe == null)
              return false; 
          } 
          return (isHandleState && ((isYkUse && isPos && isControl) || isYkExecution || isSGZ));
        }).collect(Collectors.toList());
    procYkUse(getEventMap(ykUseList), ykUseList);
    ykUseList = (List<ScadaEventInfo>)ykUseList.stream().filter(ykUse -> {
          boolean isYkUse = ObjectUtil.equals(ykUse.getAlarmType(), Integer.valueOf(1));
          boolean isPos = ((StringUtils.equalsIgnoreCase("breaker", ykUse.getFilter()) || StringUtils.equalsIgnoreCase("switch", ykUse.getFilter())) && StringUtils.equalsIgnoreCase("pos", ykUse.getPostfix()));
          return (isYkUse && isPos);
        }).collect(Collectors.toList());
    logToServer(String.format("处理遥控使用率结束，总共%d条", new Object[] { Integer.valueOf(ykUseList.size()) }));
    clearOldAndInsertNewData(jdbcClient, ykyxUseNewTable ? YKUSE_TABLE_NEW : YKUSE_TABLE, ykUseList, startDate, endDate, sdf.format(startDate), sdf.format(endDate));
  }
  
  private void procYxAccuracy(Map<Long, List<ScadaEventInfo>> eventMap) {
    boolean yxNotHandleSwitch = Constants.getBoolean("ykyx.yx.not.handle.switch", false);
    eventMap.forEach((objId, infoList) -> {
          List<ScadaEventInfo> soeEventList = (List<ScadaEventInfo>)infoList.stream().filter(()).collect(Collectors.toList());
          List<ScadaEventInfo> bitChangeEventList = (List<ScadaEventInfo>)infoList.stream().filter(()).collect(Collectors.toList());
          boolean yxNeedHandleJitter = Constants.getBoolean("ykyx.yx.need.handle.jitter", true);
          boolean yxIgnoreWhenFive = Constants.getBoolean("ykyx.yx.ignore.when.five", false);
          if (yxNeedHandleJitter) {
            yxSlidingWindow(bitChangeEventList, 4);
            yxSlidingWindow(bitChangeEventList, 2);
          } 
          if (yxIgnoreWhenFive)
            yxSlidingWindow(bitChangeEventList, 5); 
          soeEventList.forEach(());
        });
  }
  
  private void procYkSuccess(Map<Long, List<ScadaEventInfo>> eventMap) {
    eventMap.forEach((objId, infoList) -> {
          List<ScadaEventInfo> ykResultEventList = (List<ScadaEventInfo>)infoList.stream().filter(()).collect(Collectors.toList());
          ykResultEventList.forEach(());
        });
  }
  
  private void procYkUse(Map<Long, List<ScadaEventInfo>> eventMap, List<ScadaEventInfo> ykUseList) {
    boolean ykuseAllYk = Constants.getBoolean("ykyx.ykuse.all.yk", false);
    eventMap.forEach((objId, infoList) -> {
          List<ScadaEventInfo> ykUseEventList = (List<ScadaEventInfo>)infoList.stream().filter(()).collect(Collectors.toList());
          boolean yxUseNeedHandleJitter = Constants.getBoolean("ykyx.ykuse.need.handle.jitter", true);
          boolean yxUseIgnoreWhenFive = Constants.getBoolean("ykyx.ykuse.ignore.when.five", true);
          if (yxUseNeedHandleJitter) {
            yxSlidingWindow(ykUseEventList, 4);
            yxSlidingWindow(ykUseEventList, 2);
          } 
          if (yxUseIgnoreWhenFive)
            yxSlidingWindow(ykUseEventList, 5); 
          ykUseEventList.forEach(());
        });
  }
  
  public static boolean isDebugOrNotStatistics(Integer reasonCode) {
    boolean isDebug = false;
    boolean isNotStatistics = false;
    if (reasonCode != null) {
      if (DEBUG_FLAG != -1)
        isDebug = ((reasonCode.intValue() >> DEBUG_FLAG & 0x1) == 1); 
      if (NOT_STATISTICS_FLAG != -1)
        isNotStatistics = ((reasonCode.intValue() >> NOT_STATISTICS_FLAG & 0x1) == 1); 
    } 
    return (isDebug || isNotStatistics);
  }
  
  private Map<Long, List<ScadaEventInfo>> getEventMap(List<ScadaEventInfo> scadaEvents) {
    Map<Long, List<ScadaEventInfo>> eventMap = (Map<Long, List<ScadaEventInfo>>)scadaEvents.stream().collect(Collectors.groupingBy(ScadaEventInfo::getObjId));
    eventMap.forEach((objId, infoList) -> infoList.sort(Comparator.comparing(ScadaEventInfo::getOccurTime)));
    return eventMap;
  }
  
  public void yxSlidingWindow(List<ScadaEventInfo> scadaEventInfos, int num) {
    if (num == 5 && scadaEventInfos.size() >= num) {
      scadaEventInfos.forEach(event -> event.setExcludeReason(Integer.valueOf(EXCLUDE_REASON_SHAKE)));
    } else if (num == 4) {
      List<ScadaEventInfo> res = new ArrayList<>();
      for (int i = 0; i < scadaEventInfos.size(); i++) {
        res.add(scadaEventInfos.get(i));
        if (res.size() == num) {
          ScadaEventInfo first = res.get(0);
          ScadaEventInfo last = res.get(num - 1);
          long firstOccurTimeMs = first.getOccurTime().getTime() + first.getMilliSecond().intValue();
          long lastOccurTimeMs = last.getOccurTime().getTime() + last.getMilliSecond().intValue();
          boolean inTimeRange = (lastOccurTimeMs - firstOccurTimeMs <= YX_STANDARD_SECOND * 1000L);
          if (inTimeRange)
            for (int j = 0; j < num; j++)
              ((ScadaEventInfo)res.get(j)).setExcludeReason(Integer.valueOf(EXCLUDE_REASON_SHAKE));  
          res.remove(0);
        } 
      } 
    } else if (num == 2) {
      Map<Integer, List<ScadaEventInfo>> eventMap = (Map<Integer, List<ScadaEventInfo>>)scadaEventInfos.stream().collect(Collectors.groupingBy(ScadaEventInfo::getStatus));
      eventMap.forEach((status, infoList) -> infoList.sort(Comparator.comparing(ScadaEventInfo::getOccurTime)));
      eventMap.forEach((status, infoList) -> {
            List<ScadaEventInfo> res = new ArrayList<>();
            for (int i = 0; i < infoList.size(); i++) {
              res.add(infoList.get(i));
              if (res.size() == num) {
                ScadaEventInfo first = res.get(0);
                ScadaEventInfo last = res.get(num - 1);
                long firstOccurTimeMs = first.getOccurTime().getTime() + first.getMilliSecond().intValue();
                long lastOccurTimeMs = last.getOccurTime().getTime() + last.getMilliSecond().intValue();
                boolean inTimeRange = (lastOccurTimeMs - firstOccurTimeMs <= YX_STANDARD_SECOND * 1000L);
                if (inTimeRange) {
                  first.setExcludeReason(Integer.valueOf(EXCLUDE_REASON_SHAKE));
                  last.setExcludeReason(Integer.valueOf(EXCLUDE_REASON_SHAKE));
                } 
                res.remove(0);
              } 
            } 
          });
    } 
  }
  
  private void clearOldAndInsertNewData(SimpleJdbcClient jdbcClient, String tableName, List<ScadaEventInfo> list, Date startDate, Date endDate, String startDateStr, String endDateStr) throws Exception {
    clearDuplicateData(jdbcClient, tableName, startDateStr, endDateStr);
    list = (List<ScadaEventInfo>)list.stream().filter(event -> (event.getOccurTime().compareTo(startDate) >= 0 && event.getOccurTime().compareTo(endDate) < 0)).collect(Collectors.toList());
    batchInsert(jdbcClient, tableName, list);
  }
  
  private static <T> Predicate<T> distinctByKey(Function<? super T, ?> keyExtractor) {
    Map<Object, Boolean> seen = new ConcurrentHashMap<>();
    return t -> (seen.putIfAbsent(keyExtractor.apply(t), Boolean.TRUE) == null);
  }
  
  private void clearDuplicateData(SimpleJdbcClient jdbcClient, String tableName, String startDateStr, String endDateStr) throws Exception {
    String delSql = String.format("delete from " + tableName + " where occur_time >= '%s' and occur_time < '%s'", new Object[] { startDateStr, endDateStr });
    jdbcClient.update(delSql);
  }
  
  private void batchInsert(SimpleJdbcClient jdbcClient, String tableName, List<ScadaEventInfo> list) {
    if (CollectionUtil.isEmpty(list))
      return; 
    String sql = "insert into " + tableName + " (occur_time,milli_second,soe_time,soe_msecond,division_id,station_id,feeder_id,rtu_id,rtu_type,comm_type,manu_fac,dev_id,obj_id,status,content,alarm_type,context,sysid,reason_code,idx,result,is_transmit,exclude_reason,yk_of_yx) values (?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?)";
    List<List<ScadaEventInfo>> batchList = CollectionUtil.split(list, 1000);
    batchList.forEach(subList -> {
          List<Object[]> batchArgs = new ArrayList();
          subList.forEach(());
          try {
            jdbcClient.batchUpdate(sql, batchArgs);
          } catch (Exception e) {
            throw new RuntimeException(e);
          } 
        });
  }
  
  public static long randomLongNum() {
    return (new Date()).getTime() / 1000L + (long)(Math.random() * 10000.0D);
  }
}
